View source: R/tm_components.R
| tm_components | R Documentation |
Control the grouping, position, and stacking of map components (legends, titles, scale bars, etc.).
tm_components(
group_id = "",
position,
stack,
frame_combine,
equalize,
resize_as_group,
stack_margin,
offset,
frame,
frame.color,
frame.alpha,
frame.lwd,
frame.r,
bg,
bg.color,
bg.alpha
)
group_id |
id of the component group. By default set to |
position |
The position specification of the components in this group: an object created with |
stack |
stacking |
frame_combine |
put frame around all components that are drawn on the same location. Whether a frame is drawn is still decided by the |
equalize |
in case |
resize_as_group |
in case a component if rescaled because of the limited space, rescale the other components proportionally? |
stack_margin |
Margin between components. One or two values. If two values are provided, the first is the horizontal stacking margin and the second the vertical. The unit is text line heights. |
offset |
Offset margin between frame and the components block. One or two values. If two values are provided, the first is the horizontal offset and the second the vertical. The unit is text line heights. |
frame |
Should a frame be drawn? By default |
frame.color |
frame color |
frame.alpha |
frame alpha transparancy |
frame.lwd |
frame line width |
frame.r |
Radius of the rounded frame corners. 0 means no rounding. |
bg |
Background color the components block. Is usually set in each component function, but if specified here, it will overwrite them. |
bg.color |
Background color the components block. Is usually set in each component function, but if specified here, it will overwrite them. |
bg.alpha |
Background alpha transparency of the components block. Is usually set in each component function, but if specified here, it will overwrite them. |
A tmap-element
Components, Positioning of components, Grouping of components, Choropleth (Netherlands)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.