View source: R/tm_label_format.R
| tm_label_format | R Documentation |
tmap function to specify labels used in the scale functions, e.g. via the argument label.format in tm_scale_intervals().
tm_label_format(
fun,
scientific,
format,
digits,
interval.disjoint,
big.num.abbr,
prefix,
suffix,
text.separator,
text.less.than,
text.less.than_as.prefix,
text.or.more,
text.or.more_as.prefix,
text.align,
text.to.columns,
html.escape,
...
)
fun |
Function to specify the labels. It should take a numeric vector, and should return a character vector of the same size. By default it is not specified. If specified, the list items |
scientific |
Should the labels be formatted scientifically? If so, square brackets are used, and the |
format |
By default, |
digits |
Number of digits after the decimal point if |
interval.disjoint |
In case of intervals (see |
big.num.abbr |
Vector that defines whether and which abbrevations are used for large numbers. It is a named numeric vector, where the name indicated the abbreviation, and the number the magnitude (in terms on numbers of zero). Numbers are only abbrevation when they are large enough. Set it to |
prefix |
Prefix of each number |
suffix |
Suffix of each number |
text.separator |
Character string to use to separate numbers in an interval legend (default: |
text.less.than |
Character value(s) to use for 'less than'. Default |
text.less.than_as.prefix |
Should |
text.or.more |
Character value(s) to use to 'or more'. Default is |
text.or.more_as.prefix |
Should |
text.align |
Not implemented in v4 (yet). Value that determines how the numbers are aligned, |
text.to.columns |
Not implemented in v4 (yet). Logical that determines whether the text is aligned to three columns (from, text.separator, to). By default |
html.escape |
Logical that determins whther HTML code is escaped in the popups in view mode. By default |
... |
arguments passed on to |
list with formatting options
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.