View source: R/tm_component_functions.R
| tm_minimap | R Documentation |
Map component that adds a minimap in view mode.
tm_minimap(
server,
toggle,
height,
width,
margins,
between_margin,
position,
group_id,
frame,
frame.color,
frame.alpha,
frame.lwd,
frame.r,
bg,
bg.color,
bg.alpha,
z,
...
)
server |
name of the provider or an URL (see |
toggle |
should the minimap have a button to minimise it? By default |
width, height |
width and height of the component. |
margins |
margins |
between_margin |
Margin between |
position |
The position specification of the component: an object created with |
group_id |
Component group id name. All components (e.g. legends, titles, etc) with the same |
frame |
frame should a frame be drawn? |
frame.color |
frame color |
frame.alpha |
frame alpha transparancy |
frame.lwd |
frame line width |
frame.r |
Radius of the rounded frame corners. 0 means no rounding. |
bg |
Show background? |
bg.color |
Background color |
bg.alpha |
Background transparency |
z |
z index, e.g. the place of the component relative to the other componets |
... |
Arguments passed on to
|
Components, Positioning of components, Grouping of components, Choropleth (Netherlands) .doc_see_also_insets()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.