tmapAddLayerOptions: Internal tmap function to add a default value for the layer...

View source: R/tmap_options.R

tmapAddLayerOptionsR Documentation

Internal tmap function to add a default value for the layer functions. Deprecated

Description

Internal tmap function to add a default value for the layer functions. Deprecated. Use tmapSubmitOptions() instead.

Usage

tmapAddLayerOptions(option, id, value)

Arguments

option

one of: "value.const", "value.na", "value.blank", "values.var", 'values.range', "value.neutral", "scales.var"

id

name of the map variable with layer, in the format "x.y", where x is the map variable and y is the layer. It is also possible to set x only; then it applies to all layer functions.

value

value


tmap documentation built on June 26, 2026, 5:08 p.m.