tmapGetShapeMeta1: Internal method that extracts meta data from shape objects

View source: R/tmapShape.R

tmapGetShapeMeta1R Documentation

Internal method that extracts meta data from shape objects

Description

Internal method that extracts meta data from shape objects

Usage

tmapGetShapeMeta1(shp, layer, o)

Arguments

shp

the shape object

layer

(optional) the layer of the shape object

o

the list of options


tmap documentation built on June 26, 2026, 5:08 p.m.