| tmap_design_mode | R Documentation |
When the so-called "design mode" is enabled, the composition of the plot is shown explicitly in plot mode. The used color codings is printed in the console as well as information about plot size and aspect ratio.
tmap_design_mode(design.mode)
design.mode |
Logical value that determines the design mode. If omitted then the design mode is toggled. |
This function sets the global option tmap.design.mode.
It can be used as toggle function without arguments.
tmap_options()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.