Learn R Programming

tmap (version 4.4)

tmapGetShapeMeta1: Internal method that extracts meta data from shape objects

Description

Internal method that extracts meta data from shape objects

Usage

tmapGetShapeMeta1(shp, layer, o)

Arguments

shp

the shape object

layer

(optional) the layer of the shape object

o

the list of options